### Name: MPinv
### Title: Moore-Penrose Pseudoinverse of a Real-valued Matrix
### Aliases: MPinv
### Keywords: array

### ** Examples

A <- matrix(c(1, 1, 0,
              1, 1, 0,
              2, 3, 4), 3, 3)
B <- MPinv(A)
A %*% B %*% A - A  # essentially zero
B %*% A %*% B - B  # essentially zero
attr(B, "rank")    # here 2

## demonstration that "svd" and "chol" deliver essentially the same
## results for symmetric matrices:
A <- crossprod(A)
MPinv(A) - MPinv(A, method = "chol") ##  (essentially zero) 

## now a symmetric example with diagonal submatrix to `eliminate'
A <- matrix(c(1, 0, 2,
              0, 2, 3,
              2, 3, 4), 3, 3)
B <- MPinv(A, eliminate = 1:2)
A %*% B %*% A - A  # essentially zero
B %*% A %*% B - B  # essentially zero
attr(B, "rank")        # here 3  
## alternative representation of A as a list
A.list <- list(matrix(4), c(1,2), matrix(c(2,3)))
C <- MPinv(A.list)
## Not run: 
##D ## demo that eliminate can give substantial speed gains
##D A <- diag(rnorm(100))
##D A <- cbind(A, matrix(rnorm(200), 100, 2))
##D A <- rbind(A, cbind(t(A[, 101:102]), matrix(c(1, 2, 2, 1), 2, 2)))
##D system.time(for (i in 1:1000) B <-  MPinv(A))
##D ##  [1] 30.85  0.06 30.91  0.00  0.00
##D system.time(for (i in 1:1000) B <-  MPinv(A, eliminate = 1:100))
##D ##  [1] 3.10 0.00 3.11 0.00 0.00
## End(Not run)



